clear all
clc
set(0,'defaultfigurecolor',[1 1 1])

%% INFO

% Show flow curves measured with original and new friction tester for 
% C/PEEK and C/LM-PAEK. 

% Matlab version: R2023a

%% initialisation

mat_type = 1; % 1: C/PEEK, 2: C/LM-PAEK

% clear figures
figure(1), clf(1)

%% Load and plot data

% show data points (from saved data)
cd ../Flow_curve_data
if mat_type == 1
    flow_curve_labels = ["data_points_nFT_T_C-PEEK_pp_385_15.mat","data_points_oFT_T_C-PEEK_pp_385_15.mat","data_points_oFT_earlier_T_C-PEEK_pp_385_15.mat"];
elseif mat_type == 2
    flow_curve_labels = ["data_points_nFT_T_C-LM-PAEK_pp_365_15.mat","data_points_oFT_T_C-LM-PAEK_pp_365_15.mat"];
end

% plot
figure(1), hold on 
color_code = ["[0.15 0.15 0.15]","[0.0 0.45 0.74]","[0.85 0.33 0.1]"];
legend_FT = ["nFT (this work)","oFT (this work)","oFT (earlier [31])"];
for i = 1:length(flow_curve_labels)
    
    % load data
    load(flow_curve_labels(i))
    if i == 1
        plot(V_mean_vec,tau_peak_vec-d_tau_end_vec,'^','color',color_code(i),'markerfacecolor','none','markersize',6,'displayname',['Peak, $\tau_{\rm{mat,p}}$']); 
        plot(V_mean_vec,tau_mean_vec-d_tau_end_vec,'o','color',color_code(i),'markerfacecolor','none','markersize',6,'displayname',['Long-time, $\tau_{\rm{mat,\infty}}$']); 
        plot(1e-3,1e-3,'k.','color',color_code(i),'markersize',15,'displayname',legend_FT(i))
    else
        plt = plot(V_mean_vec,tau_peak_vec-d_tau_end_vec,'^','color',color_code(i),'markerfacecolor','none','markersize',6); 
        set( get( get( plt, 'Annotation'), 'LegendInformation' ), 'IconDisplayStyle', 'off' );
        plt = plot(V_mean_vec,tau_mean_vec-d_tau_end_vec,'o','color',color_code(i),'markerfacecolor','none','markersize',6);
        set( get( get( plt, 'Annotation'), 'LegendInformation' ), 'IconDisplayStyle', 'off' );
        plot(1e-3,1e-3,'k.','color',color_code(i),'markersize',15,'displayname',legend_FT(i))
    end

end
cd ../Scripts

%% plot

if mat_type == 1
    text(1.2e-2,125,'C/PEEK','interpreter','latex','fontsize',8)
elseif mat_type == 2
    text(1.2e-2,125,'C/LM-PAEK','interpreter','latex','fontsize',8)
end

ylabel('Matrix shear stress, $\tau_{\rm{mat}}$ [kPa]','interpreter','Latex','fontsize',8)
xlabel('Rate, $V$ [mm/s]','interpreter','Latex','fontsize',8)
leg = legend('location','SouthEast','interpreter','latex','box','off','fontsize',8);
leg.ItemTokenSize = [22,18];
set(gca,'XScale','log','YScale','log','fontsize',8)

% figure size 
width = 9; % single column: 9 cm, 1.5 column: 14 cm, double column: 19 cm
set(gcf,'units','centimeters','position',[5,5,width,0.75*width],'renderer','painters')
axis([1e-2 5 1 175])
grid on
box on