clear all
clc
set(0,'defaultfigurecolor',[1 1 1])

%% INFO

% Read and process temperature tests

% Version:
%   v1: 12-4-2024

% Matlab version: R2023a 


%% initialisation

figure(1), clf(1)
figure(2), clf(2)
figure(3), clf(3)

%% Load data

% --- First configuration
file_name = 'Config1_Meas2.txt';
data = readmatrix(file_name);

% interpret data
t = data(:,1); % time [s]
TC0 = data(:,2); % T reading location 0; failed
TC1 = data(:,13); % T reading location 0; failed -> from TC slot 11!
TC2 = data(:,4); % T reading location 0; failed
TC3 = data(:,15); % T reading location 0
TC4 = data(:,6); % T reading location 0
TC5 = data(:,7); % T reading location 0
TC6 = data(:,8); % T reading location 0
TC7 = data(:,9); % T reading location 0
TC8 = data(:,16); % T reading location 0
TC9 = data(:,11); % T reading location 0

figure(1), hold on
plot(t,TC0,'--','displayname','TC0 x')
plot(t,TC1,'--','displayname','TC1 x')
plot(t,TC2,'--','displayname','TC2 x')
plot(t,TC3,'displayname','TC3')
plot(t,TC4,'displayname','TC4')
plot(t,TC5,'displayname','TC5')
plot(t,TC6,'displayname','TC6')
plot(t,TC7,'displayname','TC7')
plot(t,TC8,'displayname','TC8')
plot(t,TC9,'displayname','TC9')
title('First configuration')
axis([0 70 370 400])
grid on
box on

% average values over meas range, allocated to location in contact area
Loc0 = [];
Loc1 = [];
Loc2 = [];
Loc3 = [mean(TC3)];
Loc4 = [mean(TC4)];
Loc5 = [mean(TC5)];
Loc6 = [mean(TC6)];
Loc7 = [mean(TC7)];
Loc8 = [mean(TC8)];
Loc9 = [mean(TC9)];


% --- Second configuration
file_name = 'Config2_Meas2.txt';
data = readmatrix(file_name);

% interpret data
t = data(:,1); % time [s]
TC0 = data(:,2); % T reading location 0; failed
TC1 = data(:,13); % T reading location 0; failed -> from TC slot 11!
TC2 = data(:,4); % T reading location 0; failed
TC3 = data(:,15); % T reading location 0
TC4 = data(:,6); % T reading location 0
TC5 = data(:,7); % T reading location 0
TC6 = data(:,8); % T reading location 0
TC7 = data(:,9); % T reading location 0
TC8 = data(:,16); % T reading location 0
TC9 = data(:,11); % T reading location 0

figure(2), hold on
plot(t,TC0,'--','displayname','TC0 x')
plot(t,TC1,'--','displayname','TC1 x')
plot(t,TC2,'--','displayname','TC2 x')
plot(t,TC3,'displayname','TC3')
plot(t,TC4,'displayname','TC4')
plot(t,TC5,'displayname','TC5')
plot(t,TC6,'displayname','TC6')
plot(t,TC7,'displayname','TC7')
plot(t,TC8,'displayname','TC8')
plot(t,TC9,'displayname','TC9')
title('Second configuration')
axis([0 140 370 400])
grid on
box on

% average values over meas range, allocated to location in contact area
Loc0 = [Loc0,];
Loc1 = [Loc1,];
Loc2 = [Loc2,mean(TC3)];
Loc3 = [Loc3,];
Loc4 = [Loc4,mean(TC4)];
Loc5 = [Loc5,mean(TC6)];
Loc6 = [Loc6,mean(TC5)];
Loc7 = [Loc7,mean(TC7)];
Loc8 = [Loc8,mean(TC9)];
Loc9 = [Loc9,mean(TC8)];


% --- Third configuration
file_name = 'Config3_Meas2.txt';
data = readmatrix(file_name);

% interpret data
t = data(:,1); % time [s]
TC8 = data(:,16); % T reading location 0
TC9 = data(:,11); % T reading location 0

figure(3), hold on
plot(t,TC8,'displayname','TC8')
plot(t,TC9,'displayname','TC9')
title('Third configuration')
axis([0 90 370 400])
grid on
box on

% average values over meas range, allocated to location in contact area
Loc0 = [Loc0,mean(TC8)];
Loc1 = [Loc1,mean(TC9)];

%% Compute averages for locations

Loc0_avg = mean(Loc0);
Loc1_avg = mean(Loc1);
Loc2_avg = mean(Loc2);
Loc3_avg = mean(Loc3);
Loc4_avg = mean(Loc4);
Loc5_avg = mean(Loc5);
Loc6_avg = mean(Loc6);
Loc7_avg = mean(Loc7);
Loc8_avg = mean(Loc8);
Loc9_avg = mean(Loc9);
Loc_avg = [Loc0_avg Loc1_avg Loc2_avg Loc3_avg Loc4_avg Loc5_avg Loc6_avg Loc7_avg Loc8_avg Loc9_avg]

% mean whole area
T_avg_whole = mean([Loc0_avg Loc1_avg Loc2_avg Loc3_avg Loc4_avg Loc5_avg Loc6_avg Loc7_avg Loc8_avg Loc9_avg]);

% mean contact area
T_avg_contact = mean([Loc2_avg Loc3_avg Loc4_avg Loc5_avg Loc6_avg Loc7_avg Loc8_avg Loc9_avg]);

% mean pre-heating stage
T_avg_pre = mean([Loc0_avg Loc1_avg]);

%% Deviations

T_setpoint = 385;
Loc_dev = Loc_avg - T_setpoint
T_dev_whole = T_avg_whole - T_setpoint
T_dev_contact = T_avg_contact - T_setpoint
T_dev_pre = T_avg_pre - T_setpoint



